@@ -249,7 +249,7 @@ def ProcessAlarm():
     if(i>1): peak=records.arrData[6][i-1] #New: use blue graph for triggering
     else: peak=0
     now=Tuple2Seconds(time.localtime())
-    if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40)): #Trigger Alarm
+    if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40) and now<=records.AlarmTimeWindowEnd_seconds): #Movement over trigger level and not yet beyond alarm time window => Trigger Alarm
        if(records.AlarmIsSet==True and data.AlarmIsActive==False): #alarm is set
             if(now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds): # we are in alarm time window
                 if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not yet playing
@@ -307,7 +307,7 @@ def ProcessAlarm():
 #                    MusicPlayer_Stop() #close media player
                     r=2
 
-    elif(now>=records.AlarmTimeWindowEnd_seconds): #End of alarm time window, set alarm off anyway
+    elif(now>=records.AlarmTimeWindowEnd_seconds): #Beyond of alarm time window, set alarm off anyway
         if(records.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
             print strftime("%x %X"), "************ ALARM ALARM (End of Alarm Time Window)"
             records.Trigger=data.Trigger #update Trigger level on alarm occurence
