@@ -44,8 +44,11 @@ def CreateRecordFile():
     if(not os.path.exists(str(data.RecordFolder))): #create record folder
         try:
             os.mkdir(data.RecordFolder)
-        except:
-            print "Failed to create RecordFolder!"
+        except: #can not create folder
+            print "Can not save the recorded data. The folder "+data.RecordFolder+" can not be created. Are we on a N900?"
+            txt="Can not save the recorded data. The folder\n.."+data.RecordFolder[-40:]+"\ncan not be created. Are we on a N900?"
+            QMessageBox.critical(None, "SleepAnalyser ", txt, QMessageBox.Ok) #Max 11 lines in dialog!
+            return  1 #continue application but do not store config
 
     if(data.debug==True): PrintRecordData()
 
@@ -171,13 +174,15 @@ def WriteRecord():
         str(records.arrData[2][records.Index-1]) + ", " +  \
         str(records.arrData[3][records.Index-1])
 
-    data.RecordFile.write(d+"\n")
-#    if(data.debug==True): print "Write to file:",d
-
-    if(records.Index % 30 == 0):
-        if(data.debug==True): print "Flush data from IO buffer into file"
-        data.RecordFile.flush() #Every 30 indices (5 minutes in normal mode), write data from IO buffer into file
+    try:
+        data.RecordFile.write(d+"\n")
+    #    if(data.debug==True): print "Write to file:",d
 
+        if(records.Index % 30 == 0):
+            if(data.debug==True): print "Flush data from IO buffer into file"
+            data.RecordFile.flush() #Every 30 indices (5 minutes in normal mode), write data from IO buffer into file
+    except: #could not write data
+        pass
 
 
 
@@ -190,10 +195,13 @@ def WriteRecord():
 ## Returns:     none
 ###########################################################################
 def StopRecordFile():
-    if(records.AlarmIsSet==True):
-        records.LastIndex=max(records.Index, Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
-    else: records.LastIndex=records.Index
-    data.RecordFile.close()
+    try:
+        if(records.AlarmIsSet==True):
+            records.LastIndex=max(records.Index, Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
+        else: records.LastIndex=records.Index
+        data.RecordFile.close()
+    except:
+        pass
 
 
 
