@@ -277,7 +277,13 @@ def WriteConfig():
     if(data.debug==True): print "Save configuration ("+f+")"
     if (not os.path.exists(str(data.configFolder))):
         print "Create configuration folder: ", data.configFolder
-        os.mkdir(data.configFolder)
+        try:
+            os.mkdir(data.configFolder)
+        except: #can not create folder
+            print "Can not save the configuration. The folder "+data.configFolder+" can not be created. Are we on a N900?"
+            txt="Can not save the configuration. The folder \n.."+data.configFolder[-40:]+"\n can not be created. Are we on a N900?"
+            QMessageBox.critical(None, "SleepAnalyser ", txt, QMessageBox.Ok) #Max 11 lines in dialog!
+            return #continue application but do not store config
     try:
         handle = open(f, 'w')
         config.write(handle)
