@@ -40,7 +40,11 @@ if(data.debug==True): print "Languages:", DEFAULT_LANGUAGES
 
 # Try to get the languages from the default locale
 if(data.language==""):
-    lc, encoding = locale.getdefaultlocale()
+    try:
+        lc, encoding = locale.getdefaultlocale()
+    except:
+        lc="en_US"
+        encoding="UTF8"
     print "Locale:", lc, ", Encoding:", encoding
     if lc:
         languages = [lc]
